first { element: is; completely: ignored; }

body
{
  margin: 0px;
  padding: 6px 2px;
  background-color: /*{background_color}*/;
  color: /*{text_color}*/;
  font-size: medium;
}

h1, h2, h3, h4, h5, h6
{
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  overflow: hidden;
  margin: 5pt 0;
  padding: 2pt 5pt;
  background-color: /*{headings_background_color}*/;
  color: /*{text_color}*/;
}

p, div, table, ul, li
{
  font-size: medium;
}

span.citation
{
  font-size: 90%;
}

ul li
{
  margin-right: 5pt;
}
ul li a
{
  text-decoration: none;
  color: /*{link_color}*/;
}
ul li a:hover
{
  text-decoration: underline;
  color: /*{link_hover_color}*/;
}

div#wiki_otherlangs
{
  clear: both;
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  background-color: /*{shaded_text_background_color}*/;
  padding: 5pt;
  color: /*{text_color}*/;
}

div#bodyContent
{
  color: /*{text_color}*/;
}
div#bodyContent *
{
  color: /*{text_color}*/;
}

/* Bullet list definition gracefully gottened from wikipedia - since we're
 * showing their data, we should really present it like it was intended. So, we
 * use their bullet. */
div#bodyContent ul
{
  list-style-type: square;
  margin: 0 1em;
  padding: 0 1em;
  list-style-image: url(bullet.gif);
}
div#bodyContent ul li
{
  display: list-item;
}
div#bodyContent a
{
  text-decoration: none;
  color: /*{link_color}*/;
}
div#bodyContent a:hover
{
  text-decoration: underline;
  color: /*{link_hover_color}*/;
}

/* table for embedded media clip boxes */
table.metadata, table.ambox
{
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  position: relative;
  left: 50%;
  width: 50%;
  margin: 5pt 0;
  padding: 5pt;
}

table.infobox
{
  clear: right;
  float: right;
  width: 150pt;
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  background-color: /*{table_background_color}*/;
  margin: 5pt 2pt 0 5pt;
}

table.bordered
{
  clear: both;
  display: inline-block;
  margin: 5pt 2pt 0 5pt;
}

table.infobox th
{
  padding: 2pt;
  background-color: /*{alternate_table_background_color}*/;
  color: /*{text_color}*/;
}

table.gallery
{
  clear: both;
  display: block;
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  background-color: /*{table_background_color}*/;
  margin: 5pt 0;
}

table#toc
{
  display: none;
}

/*
We're hiding the TOC, as it currently links directly to the wikipedia URL, not
relatively to the anchor inside the document, which make it open up in an
external browser - not really what we want it to do...
table#toc
{
border: 1px dotted silver;
background: #f0f0f0;

}
  #toctitle h2
  {
  font-size: 11pt;
  background: silver;
  padding: 2pt;
}
  table#toc ul
  {
  list-style: none;
}
  table#toc a,table#toc a span
  {
  color: #424280;
}
  table#toc a:hover,table#toc a:hover span
  {
  color: #7E7EFF;
}
 */

/* heading text - e.g. "This article is about the band", etc. */
div.dablink
{
  width: 100%;
  text-align: left;
  font-style: italic;
  color: /*{text_color}*/;
}
div#contentSub
{
  width: 100%;
  text-align: right;
  color: gray;
}
div#jump-to-nav
{
  width: 100%;
  text-align: right;
  color: gray;
  margin-right: 5pt;
}
div#contentSub a, div#jump-to-nav a, div.dablink a
{
  color: /*{link_hover_color}*/;
}

div#stub
{
  clear: right;
  background-color: /*{shaded_text_background_color}*/;
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  width: 80%;
  padding: 5pt;
  margin-bottom: 10pt;
  margin-left: auto;
  margin-right: auto;
}

table.wikitable
{
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  border-collapse: collapse;
  margin: 5pt;
  background-color: /*{table_background_color}*/;
}
table.wikitable th
{
  padding: 2pt;
  background-color: /*{alternate_table_background_color}*/;
}
table.wikitable td
{
  padding: 2pt;
  background-color: /*{table_background_color}*/;
}

table.navbox
{
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  border-collapse: collapse;
  margin: 5pt 2% 5pt 2%;
  width: 96%;
  background-color: /*{shaded_text_background_color}*/;
}
table.navbox td
{
  background-color: /*{table_background_color}*/;
}

/*  article thumbnail images */
div.thumb
{
  -webkit-border-radius: 4px;
  -khtml-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  margin: 5pt;
  padding: 2pt;
  width: auto;
  background-color: /*{table_background_color}*/;
}

div.thumbinner
{
  text-align: center;
  overflow: hidden;
}

div.thumbimage
{
  margin: 2pt 0;
}

/* captions for thumbnail images */
div.thumbcaption
{
  border: none;
  text-align: left;
  line-height: 1.4em;
  font-size: smaller;
}

div.magnify
{
  float: right;
  border: none !important;
  background: none !important;
}

div.tright
{
  clear: right;
  float: right;
}
div.tleft
{
  float: left;
  clear: left;
}

div.medialist ul li
{
  list-style: none;
}

div#ogg_player_1, div#ogg_player_2, div#ogg_player_3, div#ogg_player_4, div#ogg_player_5, div#ogg_player_6, div#ogg_player_7, div#ogg_player_8, div#ogg_player_9, div#ogg_player_10, div#ogg_player_11, div#ogg_player_12, div#ogg_player_13
{
  display: none;
}

div#jump-to-nav, div.NavFrame, table.metadata
{
  display: none;
}

div.medialist table
{
  margin: 5pt;
  width: 100%;
}
